@@ -1,6 +1,7 @@
 from itertools import chain
 import pytest
 
+from datalad_next.datasets import Dataset
 from datalad_next.runners import (
     call_git_success,
 )
@@ -38,9 +39,9 @@ def test_status_homogeneity(modified_dataset):
         dict(path=ds.pathobj, eval_submodule_state='commit', recursive='repository'),
         dict(path=ds.pathobj, eval_submodule_state='commit', recursive='submodules'),
         # without untracked
-        dict(path=ds.pathobj, untracked='no', recursive='no'),
-        dict(path=ds.pathobj, untracked='no', recursive='repository'),
-        dict(path=ds.pathobj, untracked='no', recursive='submodules'),
+        dict(path=ds.pathobj, untracked=None, recursive='no'),
+        dict(path=ds.pathobj, untracked=None, recursive='repository'),
+        dict(path=ds.pathobj, untracked=None, recursive='submodules'),
         # special untracked modes
         dict(path=ds.pathobj, untracked='whole-dir', recursive='no'),
         dict(path=ds.pathobj, untracked='whole-dir', recursive='repository'),
@@ -146,7 +147,8 @@ def _assert_testcases(st, tc):
         assert st[c['name']].status == c['status']
         mod_types = st[c['name']].modification_types
         if 'qual' in c:
-            assert set(mod_types) == set(c['qual'])
+            assert set(mod_types) == set(c['qual']), \
+                f'Mismatch for {c=!r}'
         else:
             assert mod_types is None
 
@@ -253,3 +255,17 @@ def test_status_nohead_staged(tmp_path):
         {i.name: i for i in iter_gitstatus(tmp_path)},
         [{'name': 'probe', 'status': GitDiffStatus.addition}],
     )
+
+
+def test_status_submodule_added(existing_dataset, no_result_rendering):
+    p = existing_dataset.pathobj
+    subm_name = 'sub'
+    Dataset(p / subm_name).create()
+    assert call_git_success(
+        ['submodule', '--quiet', 'add', f'./{subm_name}', subm_name],
+        cwd=p)
+    # check that we get the status on a submodule that was just added with
+    # no additional changes
+    res = list(iter_gitstatus(p, recursive='monolithic'))
+    assert any(i.name == subm_name and i.gitsha and i.prev_gitsha is None
+               for i in res)
