@@ -8,7 +8,6 @@ import subprocess
 import pytest
 from tempfile import NamedTemporaryFile
 from time import sleep
-from unittest.mock import patch
 from urllib.request import urlopen
 
 from datalad_next.datasets import Dataset
@@ -16,9 +15,9 @@ from datalad_next.runners import (
     call_git_lines,
     call_git_success,
 )
-from datalad_next.tests.utils import (
+from datalad_next.utils import patched_env
+from .utils import (
     HTTPPath,
-    SkipTest,
     WebDAVPath,
     assert_ssh_access,
     external_versions,
@@ -122,8 +121,7 @@ def tmp_keyring():
         # already when ConfigManager would open it for reading
         tf.close()
         backend.file_path = tf.name
-        with patch.dict(os.environ,
-                        {'DATALAD_TESTS_TMP_KEYRING_PATH': tf.name}):
+        with patched_env(DATALAD_TESTS_TMP_KEYRING_PATH=tf.name):
             yield backend
 
     backend.file_path = prev_fpath
@@ -133,17 +131,21 @@ def tmp_keyring():
 # sadly, this is defined inline and cannot be reused directly
 standard_gitconfig = """\
 [user]
-        name = DataLad Tester
-        email = test@example.com
+    name = DataLad Tester
+    email = test@example.com
 [core]
-	askPass =
+    askPass =
 [datalad "log"]
-        exc = 1
+    exc = 1
+[datalad "extensions"]
+    # load the next extension to be able to test patches of annex remotes
+    # that run in subprocesses
+    load = next
 [annex "security"]
-	# from annex 6.20180626 file:/// and http://localhost access isn't
-	# allowed by default
-	allowed-url-schemes = http https file
-	allowed-http-addresses = all
+    # from annex 6.20180626 file:/// and http://localhost access isn't
+    # allowed by default
+    allowed-url-schemes = http https file
+    allowed-http-addresses = all
 [protocol "file"]
     # since git 2.38.1 cannot by default use local clones for submodules
     # https://github.blog/2022-10-18-git-security-vulnerabilities-announced/#cve-2022-39253
@@ -167,7 +169,7 @@ def datalad_cfg():
     here was only introduced with that version.
     """
     if external_versions['cmd:git'] < "2.32":
-        raise SkipTest(
+        pytest.skip(
             "Git configuration redirect via GIT_CONFIG_GLOBAL "
             "only supported since Git v2.32"
         )
@@ -180,7 +182,7 @@ def datalad_cfg():
         # we must close, because windows does not like the file being open
         # already when ConfigManager would open it for reading
         tf.close()
-        with patch.dict(os.environ, {'GIT_CONFIG_GLOBAL': tf.name}):
+        with patched_env(GIT_CONFIG_GLOBAL=tf.name):
             cfg.reload(force=True)
             yield cfg
     # reload to put the previous config in effect again
@@ -307,6 +309,7 @@ def modified_dataset(tmp_path_factory):
           (use "git restore --staged <file>..." to unstage)
                 new file:   dir_m/file_a
                 new file:   file_a
+                new file:   file_am
 
         Changes not staged for commit:
           (use "git add/rm <file>..." to update what will be committed)
@@ -322,6 +325,7 @@ def modified_dataset(tmp_path_factory):
                 modified:   dir_sm/sm_nm (new commits, modified content)
                 modified:   dir_sm/sm_nmu (new commits, modified content, untracked content)
                 modified:   dir_sm/sm_u (untracked content)
+                modified:   file_am
                 deleted:    file_d
                 modified:   file_m
 
@@ -332,6 +336,7 @@ def modified_dataset(tmp_path_factory):
                 dir_u/file_u
                 file_u
 
+
     Suffix indicates the ought-to state (multiple possible):
 
     a - added
@@ -404,6 +409,11 @@ def modified_dataset(tmp_path_factory):
         pobj = obj.pathobj if isinstance(obj, Dataset) else obj
         (pobj / 'file_a').write_text('added')
         assert call_git_success(['add', 'file_a'], cwd=pobj)
+    # added and then modified file
+    file_am_obj = ds.pathobj / 'file_am'
+    file_am_obj.write_text('added')
+    assert call_git_success(['add', 'file_am'], cwd=ds.pathobj)
+    file_am_obj.write_text('modified')
 
     # record git-status output as a reference
     status_start = call_git_lines(['status'], cwd=ds.pathobj)
@@ -561,15 +571,15 @@ def httpbin(httpbin_service):
     in some cases it is simply not desirable to run a test. For example,
     the appveyor workers are more or less constantly unable to access the
     public service. This fixture is evaluated at function-scope and
-    raises ``SkipTest`` whenever any of these undesired conditions is
+    skips the test whenever any of these undesired conditions is
     detected. Otherwise it just relays ``httpbin_service``.
     """
     if os.environ.get('DATALAD_TESTS_NONETWORK'):
-        raise SkipTest(
+        pytest.skip(
             'Not running httpbin-based test: NONETWORK flag set'
         )
     if 'APPVEYOR' in os.environ and 'DEPLOY_HTTPBIN_IMAGE' not in os.environ:
-        raise SkipTest(
+        pytest.skip(
             "Not running httpbin-based test on appveyor without "
             "docker-deployed instance -- too unreliable"
         )
@@ -591,7 +601,7 @@ def datalad_interactive_ui(monkeypatch):
        > assert ... datalad_interactive_ui.log
     """
     from datalad_next.uis import ui_switcher
-    from datalad_next.tests.utils import InteractiveTestUI
+    from .utils import InteractiveTestUI
 
     with monkeypatch.context() as m:
         m.setattr(ui_switcher, '_ui', InteractiveTestUI())
@@ -611,7 +621,7 @@ def datalad_noninteractive_ui(monkeypatch):
        > assert ... datalad_interactive_ui.log
     """
     from datalad_next.uis import ui_switcher
-    from datalad_next.tests.utils import TestUI
+    from .utils import TestUI
 
     with monkeypatch.context() as m:
         m.setattr(ui_switcher, '_ui', TestUI())
@@ -621,7 +631,7 @@ def datalad_noninteractive_ui(monkeypatch):
 @pytest.fixture(autouse=False, scope="session")
 def sshserver_setup(tmp_path_factory):
     if not os.environ.get('DATALAD_TESTS_SSH'):
-        raise SkipTest(
+        pytest.skip(
             "set DATALAD_TESTS_SSH=1 to enable")
 
     # query a bunch of recognized configuration environment variables,
@@ -666,10 +676,13 @@ def sshserver_setup(tmp_path_factory):
 
 @pytest.fixture(autouse=False, scope="function")
 def sshserver(sshserver_setup, datalad_cfg, monkeypatch):
+    # strip any leading / from the path, we add one, and
+    # only one below
+    sshserver_path = sshserver_setup['SSH_PATH'].lstrip('/')
     baseurl = f"ssh://{sshserver_setup['SSH_LOGIN']}" \
         f"@{sshserver_setup['HOST']}" \
         f":{sshserver_setup['SSH_PORT']}" \
-        f"/{sshserver_setup['SSH_PATH']}"
+        f"/{sshserver_path}"
     with monkeypatch.context() as m:
         m.setenv("DATALAD_SSH_IDENTITYFILE", sshserver_setup['SSH_SECKEY'])
         # force reload the config manager, to ensure the private key setting
